# DyNN: Neural Network routines for DyNet

[![Build Status](https://travis-ci.org/pmichel31415/dynn.svg?branch=master)](https://travis-ci.org/pmichel31415/dynn) [![Documentation Status](https://readthedocs.org/projects/dynn/badge/?version=latest)](https://dynn.readthedocs.io/en/latest/?badge=latest)

A bunch of useful functions and syntactic sugar to make writing neural networks in [DyNet](http://dynet.io/) easier.

## Prerequisite

You will need to install DyNet as explained [here](http://dynet.readthedocs.io/en/latest/python.html)
